@@ -4,8 +4,6 @@
 from .common import _seemsValidText
 from telegram_util import matchKey
 
-SHORT_ARTICLE = ['每日书摘']
-
 def _seemsValidRawArticle(soup, text_limit = 500):
 	if not _seemsValidText(soup, limit = text_limit):
 		return False
@@ -13,15 +11,39 @@ def _seemsValidRawArticle(soup, text_limit = 500):
 
 def getMatters(soup):
 	main = soup.find("div", class_ = "u-content")
-	item = soup.find("div", id = "__next")
-	if not item:
+	try:
+		item = main.parent.parent.parent.parent.findNext('p')
+	except:
 		return main
-	item = item.findNext('p')
 	while item:
 		main.insert(len(main.contents), item)
 		item = item.findNext('p')
 	return main
 
+def getDQ(soup):
+	pivot = soup.find('div', id='yd-PlugIn')
+	if not pivot:
+		pivot = soup.find('footer', class_='repost')
+	for item in pivot.find_next_siblings():
+		item.decompose()
+	pivot.decompose()
+	return soup
+
+def getUdn(soup):
+	main = soup.find("main")
+	try:
+		item = main.parent.parent.parent.findNext()
+	except:
+		return main
+	while item:
+		if (item.text or '').strip().startswith('｜延伸閱讀｜'):
+			return main
+		if item.get('id') == 'extension':
+			return main
+		main.insert(len(main.contents), item)
+		item = item.findNext()
+	return main
+
 def _getInnerArticle_(soup, domain):	
 	applicators = [
 		lambda x: x.find("article"),
@@ -75,21 +97,24 @@ def _getInnerArticle_(soup, domain):
 		'biede.com': [lambda x: x.find("div", class_ = 'lay'),],
 		'www.thewechatproject.org': [lambda x: x.find("div", class_ = 'post-content__body'),],
 		'freewechat.com': [lambda x: x.find("div", class_ = 'rich_media_content'),],
+		'allnow.com': [lambda x: x.find("div", id = 'article-content'),],
 	}
-	is_short = matchKey(soup.text, SHORT_ARTICLE)
-	text_limit = 150 if is_short else 500
-	for applicator in applicators:
-		candidate = applicator(soup)
-		if _seemsValidRawArticle(candidate, text_limit = text_limit):
-			soup = candidate
 	if 'matters.news' in domain:
 		return getMatters(soup)
+	if 'opinion.udn.com' in domain:
+		return getUdn(soup)
+	for applicator in applicators:
+		candidate = applicator(soup)
+		if _seemsValidRawArticle(candidate, text_limit = 500):
+			soup = candidate
 	for d, applicators in domain_specific_applicators.items():
 		if d in domain:
 			for applicator in applicators:
 				candidate = applicator(soup)
 				if candidate:
 					soup = candidate
+	if 'dq.yam.com' in domain:
+		return getDQ(soup)
 	return soup
 
 def _getInnerArticle(soup, domain):
