@@ -10,7 +10,7 @@ import sys
 OFFTOPIC_TAG = ['small', 'address', 'meta', 'script', 'sup', 'svg']
 
 OFFTOPIC_ATT = [
-	'latest', 'more', 'facebook',
+	'latest', 'more', 'facebook', 'ts-fab-wrapper',
 	'cn-carousel-medium-strip', 'video__end-slate__top-wrapper', 'metadata', 
 	'el__article--embed', 'signup', 'related', 'disclaimer', 'off-screen', 
 	'story-body__unordered-list', 'story-image-copyright', 'article-header', 
@@ -20,7 +20,7 @@ OFFTOPIC_ATT = [
 	't_callout', 'add-interest', 'bb-newsletter', 'popover', 'toast', 'after-article', 
 	'submeta', 'rich-link__container', 'content__meta-container', 'mw-editsection',
 	'noprint', 'jump-to-nav', 'toctitle', 'reflist', 'contentSub',
-	'参考文献', '引用', '网页', 'printfooter', 'catlinks', 'footer', 'Post Bottom',
+	'参考文献', '引用', '网页', 'printfooter', 'catlinks', 'Post Bottom',
 	'ad-unit', 'box-ad', "class : ['tabs']", "class : ['hd']", 'NYT_BELOW_MAIN_CONTENT_REGION',
 	'NYT_TOP_BANNER_REGION', 'g-inlineguide', 'entry-meta-bar', 'extra-hatom-entry-title',
 	'list-unstyled', 'hide_word', 'single-header', 'post-pagination',
@@ -31,7 +31,8 @@ OFFTOPIC_ATT = [
 	'taglist', 'donate', 'see-also', 'donation-box', 'license__Container',
 	'field-photo-credit', 'Avatar', 'floating-share', 'meta-box', 'tag-list',
 	'tools__ShareIconBlock', 'aside__Container', 'MetadataAndTool', 'DesktopAsideBlock',
-	'StyledSeparationCurve', 'separation-curve', "['extending']"
+	'StyledSeparationCurve', 'separation-curve', "['extending']", "['meta-tag']",
+	'sharedaddy',
 ]
 
 OFFTOPIC_ATT_WITH_EXCEPTION = {
@@ -42,6 +43,7 @@ OFFTOPIC_ATT_WITH_EXCEPTION = {
 	'copyright': ['and'],
 	'navbar': ['single-post'],
 	'button': ['image-container', 'imageViewer', 'tabindex'],
+	'footer': ['lodestar-footer-image']
 }
 
 OFFTOPIC_CLASSES = ['ads']
